==> edbuildr_0.1.1.tar.gz: edbuildr/R/globals.R <==
utils::globalVariables(c("B11", "C11", 'C24', "COLIn", "CONUM", "CONUM_1", "CONUM_2", "County", "County_1", "County_2",
                         "District Enrollment, F33", "District Level", "District Name", "ENROLL", "ENROLL_1",
                         "ENROLL_2", "Enrollment, CCD", "FRL_rate", "FRL_rate_1", "FRL_rate_2", "GEOID", "GEOID.1",
                         "IDCENSUS", "L12", "LOCREV_adj", "LOCREV_adj_PP", "LOCREV_adj_noV92adj",
                         "LOC_PROPERTY_SALE", "LRPP_1", "LRPP_2", "LRPP_cola_1", "LRPP_cola_2", "LR_1", "LR_2",
                         "MHI_1", "MHI_2", "MPV_1", "MPV_2", "NAME_1", "NAME_2", "NCESID", "NCESID_1", "NCESID_2",
                         "Neighbor Level", "Neighbor Name", "Neighbor Percent FRL",
                         "Percent Difference in Local Revenue Per Pupil",
                         "Percent Difference in Students Per Square Mile",
                         "Region", "SLRPP_1", "SLRPP_2", "SLRPP_cola_1", "SLRPP_cola_2", "SLR_1",
                         "SLR_2", "SRPP_1", "SRPP_2", "SRPP_cola_1", "SRPP_cola_2", "SR_1",
                         "SR_2", "STATE", "STATE_FIPS", "STATE_FIPS_1", "STATE_FIPS_2", "STREV_adj",
                         "STREV_adj_PP", "STREV_adj_noV92adj", "ST_CAPITAL", "StPop_1", "StPop_2",
                         "StPovRate_1", "StPovRate_2", "StPov_1", "StPov_2", 'State', "State_1", "State_2", "TFEDREV",
                         "TLOCREV", "TPop_1", "TPop_2", "TSTREV", "U11", "V33", "V92", "X", "YRDATA", "all_of",
                         "amInd_AKK_diff", "asian_pi_diff", "black_diff", "d2plus_races_1", "d2plus_races_2",
                         "dAmIndian_Aknative_1", "dAmIndian_Aknative_2", "dAsian_PI_1", "dAsian_PI_2",
                         "dBlack_1", "dBlack_2", "dEnroll_district", "dEnroll_district_1",
                         "dEnroll_district_2", "dFRL", "dFRL_1", "dFRL_2", "dHawaiian_PI_1", "dHawaiian_PI_2",
                         "dHispanic_1", "dHispanic_2", "dIEP_1", "dIEP_2", "dLEP_1", "dLEP_2",
                         "dOperational_schools_1", "dOperational_schools_2", "dType_1", "dType_2",
                         "dUrbanicity_1", "dUrbanicity_2", "dWhite_1", "dWhite_2", "enroll_cdd_diff",
                         "enroll_f33_diff", "frl_diff", "frl_rate_diff", "hawaiian_pi_diff", "hispanic_diff",
                         "iep_diff", "lep_diff", "lr_diff", "lrpp_diff_abs", "lrpp_diff_pct", "mhi_diff_abs",
                         "mhi_diff_pct", "mpv_diff_abs", "mpv_diff_pct", "mult_race_diff", "op_schools_diff",
                         "pctFSL_Local", "pctFSL_State", "pctNonwhite_1", "pctNonwhite_2",
                         "pctnonwhite_diff", "povrate_diff", "sdType", "sd_area_1", "sd_area_2", "sd_area_diff",
                         "sd_type_1", "sd_type_2", "slr_diff", "slrpp_diff_abs", "slrpp_diff_pct", "sr_diff",
                         "srpp_diff_abs", "srpp_diff_pct", "state_code", "state_name", "stpop_diff",
                         "stpov_diff", "student_per_sq_mile_1", "student_per_sq_mile_2",
                         "student_per_sq_mile_diff", "tpop_diff", "u_id", "white_diff", "year",
                         "LRPP", "Local Revenue PP", "MHI", "MPV", "Percent FRL", "Percent Nonwhite", "Poverty Rate",
                         "SLRPP", "SRPP", "StPovRate", "State Revenue PP", "Total Revenue PP",
                         "pctNonwhite", "code"))

==> edbuildr_0.3.0.tar.gz: edbuildr/R/globals.R <==
utils::globalVariables(c("B11", "C11", 'C24', "COLIn", "CONUM", "CONUM_1", "CONUM_2", "County", "County_1", "County_2",
                         "District Enrollment, F33", "District Level", "District Name", "ENROLL", "ENROLL_1",
                         "ENROLL_2", "Enrollment, CCD", "FRL_rate", "FRL_rate_1", "FRL_rate_2", "GEOID", "GEOID.1",
                         "IDCENSUS", "L12", "LOCREV_adj", "LOCREV_adj_PP", "LOCREV_adj_noV92adj",
                         "LOC_PROPERTY_SALE", "LRPP_1", "LRPP_2", "LRPP_cola_1", "LRPP_cola_2", "LR_1", "LR_2",
                         "MHI_1", "MHI_2", "MPV_1", "MPV_2", "NAME_1", "NAME_2", "NCESID", "NCESID_1", "NCESID_2",
                         "Neighbor Level", "Neighbor Name", "Neighbor Percent FRL",
                         "Percent Difference in Local Revenue Per Pupil",
                         "Percent Difference in Students Per Square Mile",
                         "Region", "SLRPP_1", "SLRPP_2", "SLRPP_cola_1", "SLRPP_cola_2", "SLR_1",
                         "SLR_2", "SRPP_1", "SRPP_2", "SRPP_cola_1", "SRPP_cola_2", "SR_1",
                         "SR_2", "STATE", "STATE_FIPS", "STATE_FIPS_1", "STATE_FIPS_2", "STREV_adj",
                         "STREV_adj_PP", "STREV_adj_noV92adj", "ST_CAPITAL", "StPop_1", "StPop_2",
                         "StPovRate_1", "StPovRate_2", "StPov_1", "StPov_2", 'State', "State_1", "State_2", "TFEDREV",
                         "TLOCREV", "TPop_1", "TPop_2", "TSTREV", "U11", "V33", "V92", "X", "YRDATA", "all_of",
                         "amInd_AKK_diff", "asian_pi_diff", "black_diff", "d2plus_races_1", "d2plus_races_2",
                         "dAmIndian_Aknative_1", "dAmIndian_Aknative_2", "dAsian_PI_1", "dAsian_PI_2",
                         "dBlack_1", "dBlack_2", "dEnroll_district", "dEnroll_district_1",
                         "dEnroll_district_2", "dFRL", "dFRL_1", "dFRL_2", "dHawaiian_PI_1", "dHawaiian_PI_2",
                         "dHispanic_1", "dHispanic_2", "dIEP_1", "dIEP_2", "dLEP_1", "dLEP_2",
                         "dOperational_schools_1", "dOperational_schools_2", "dType_1", "dType_2",
                         "dUrbanicity_1", "dUrbanicity_2", "dWhite_1", "dWhite_2", "enroll_cdd_diff",
                         "enroll_f33_diff", "frl_diff", "frl_rate_diff", "hawaiian_pi_diff", "hispanic_diff",
                         "iep_diff", "lep_diff", "lr_diff", "lrpp_diff_abs", "lrpp_diff_pct", "mhi_diff_abs",
                         "mhi_diff_pct", "mpv_diff_abs", "mpv_diff_pct", "mult_race_diff", "op_schools_diff",
                         "pctFSL_Local", "pctFSL_State", "pctNonwhite_1", "pctNonwhite_2",
                         "pctnonwhite_diff", "povrate_diff", "sdType", "sd_area_1", "sd_area_2", "sd_area_diff",
                         "sd_type_1", "sd_type_2", "slr_diff", "slrpp_diff_abs", "slrpp_diff_pct", "sr_diff",
                         "srpp_diff_abs", "srpp_diff_pct", "state_code", "state_name", "stpop_diff",
                         "stpov_diff", "student_per_sq_mile_1", "student_per_sq_mile_2",
                         "student_per_sq_mile_diff", "tpop_diff", "u_id", "white_diff", "year",
                         "LRPP", "Local Revenue PP", "MHI", "MPV", "Percent FRL", "Percent Nonwhite", "Poverty Rate",
                         "SLRPP", "SRPP", "StPovRate", "State Revenue PP", "Total Revenue PP",
                         "pctNonwhite", "code", "LR", "LRPP_cnty", "LRPP_state", "LR_cnty", "LR_state",
                         "NAME", "SLRPP_cnty", "SLRPP_diff", "SLRPP_state", "SRPP_cnty", "SRPP_state",
                         "enroll_f33", "outcome", "state_id", "dIEP"))
